<?php

namespace Webhopers\Multivendor\Policies;

use Litepie\User\Contracts\UserPolicy;
use Webhopers\Multivendor\Models\Multivendor;

class MultivendorPolicy
{

    /**
     * Determine if the given user can view the multivendor.
     *
     * @param UserPolicy $user
     * @param Multivendor $multivendor
     *
     * @return bool
     */
    public function view(UserPolicy $user, Multivendor $multivendor)
    {
        if ($user->canDo('multivendor.multivendor.view') && $user->isAdmin()) {
            return true;
        }

        return $multivendor->user_id == user_id() && $multivendor->user_type == user_type();
    }

    /**
     * Determine if the given user can create a multivendor.
     *
     * @param UserPolicy $user
     * @param Multivendor $multivendor
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('multivendor.multivendor.create');
    }

    /**
     * Determine if the given user can update the given multivendor.
     *
     * @param UserPolicy $user
     * @param Multivendor $multivendor
     *
     * @return bool
     */
    public function update(UserPolicy $user, Multivendor $multivendor)
    {
        if ($user->canDo('multivendor.multivendor.edit') && $user->isAdmin()) {
            return true;
        }

        return $multivendor->user_id == user_id() && $multivendor->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given multivendor.
     *
     * @param UserPolicy $user
     * @param Multivendor $multivendor
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Multivendor $multivendor)
    {
        return $multivendor->user_id == user_id() && $multivendor->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given multivendor.
     *
     * @param UserPolicy $user
     * @param Multivendor $multivendor
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Multivendor $multivendor)
    {
        if ($user->canDo('multivendor.multivendor.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given multivendor.
     *
     * @param UserPolicy $user
     * @param Multivendor $multivendor
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Multivendor $multivendor)
    {
        if ($user->canDo('multivendor.multivendor.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
